// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "vntask.h"
#include <QDebug>

/**
 * @brief VNTask::VNTask
 * @param parent
 */
VNTask::VNTask(QObject *parent)
    : QObject(parent)
    , QRunnable()
{
    // qInfo() << "VNTask constructor called";
}
