/****************************************************************************
** Meta object code from reading C++ file 'web_engine_handler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../handler/web_engine_handler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'web_engine_handler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16WebEngineHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto WebEngineHandler::qt_create_metaobjectdata<qt_meta_tag_ZN16WebEngineHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebEngineHandler",
        "targetChanged",
        "",
        "requestShowMenu",
        "Menu",
        "type",
        "QPoint",
        "pos",
        "requesetCallJsSynchronous",
        "func",
        "triggerWebAction",
        "QWebEnginePage::WebAction",
        "action",
        "requestMessageDialog",
        "VNoteMessageDialogHandler::MessageType",
        "loadRichText",
        "viewPicture",
        "filePath",
        "popupToast",
        "message",
        "msgId",
        "playingVoice",
        "isPlay",
        "saveAudio",
        "createNote",
        "onCallJsResult",
        "QVariant",
        "result",
        "onContextMenuRequested",
        "QWebEngineContextMenuRequest*",
        "request",
        "onInsertVoiceItem",
        "voicePath",
        "voiceSize",
        "onThemeChanged",
        "onSaveMenuParam",
        "json",
        "onMenuClicked",
        "ActionManager::ActionKind",
        "kind",
        "onPaste",
        "isVoice",
        "target",
        "PictureMenu",
        "VoiceMenu",
        "TxtMenu",
        "MaxMenu"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'targetChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestShowMenu'
        QtMocHelpers::SignalData<void(enum Menu, const QPoint &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'requesetCallJsSynchronous'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'triggerWebAction'
        QtMocHelpers::SignalData<void(QWebEnginePage::WebAction)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'requestMessageDialog'
        QtMocHelpers::SignalData<void(VNoteMessageDialogHandler::MessageType)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 5 },
        }}),
        // Signal 'loadRichText'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewPicture'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'popupToast'
        QtMocHelpers::SignalData<void(const QString &, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Int, 20 },
        }}),
        // Signal 'playingVoice'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'saveAudio'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'createNote'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCallJsResult'
        QtMocHelpers::SlotData<void(const QVariant &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'onContextMenuRequested'
        QtMocHelpers::SlotData<void(QWebEngineContextMenuRequest *)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'onInsertVoiceItem'
        QtMocHelpers::SlotData<void(const QString &, quint64)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 32 }, { QMetaType::ULongLong, 33 },
        }}),
        // Slot 'onThemeChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSaveMenuParam'
        QtMocHelpers::SlotData<void(int, const QVariant &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { 0x80000000 | 26, 36 },
        }}),
        // Slot 'onMenuClicked'
        QtMocHelpers::SlotData<void(ActionManager::ActionKind)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'onPaste'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'target'
        QtMocHelpers::PropertyData<QObject*>(42, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Menu'
        QtMocHelpers::EnumData<enum Menu>(4, 4, QMC::EnumFlags{}).add({
            {   43, Menu::PictureMenu },
            {   44, Menu::VoiceMenu },
            {   45, Menu::TxtMenu },
            {   46, Menu::MaxMenu },
        }),
    };
    return QtMocHelpers::metaObjectData<WebEngineHandler, qt_meta_tag_ZN16WebEngineHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebEngineHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WebEngineHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WebEngineHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16WebEngineHandlerE_t>.metaTypes,
    nullptr
} };

void WebEngineHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebEngineHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->targetChanged(); break;
        case 1: _t->requestShowMenu((*reinterpret_cast<std::add_pointer_t<enum Menu>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 2: _t->requesetCallJsSynchronous((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->triggerWebAction((*reinterpret_cast<std::add_pointer_t<QWebEnginePage::WebAction>>(_a[1]))); break;
        case 4: _t->requestMessageDialog((*reinterpret_cast<std::add_pointer_t<VNoteMessageDialogHandler::MessageType>>(_a[1]))); break;
        case 5: _t->loadRichText(); break;
        case 6: _t->viewPicture((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->popupToast((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->playingVoice((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->saveAudio(); break;
        case 10: _t->createNote(); break;
        case 11: _t->onCallJsResult((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 12: _t->onContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QWebEngineContextMenuRequest*>>(_a[1]))); break;
        case 13: _t->onInsertVoiceItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint64>>(_a[2]))); break;
        case 14: _t->onThemeChanged(); break;
        case 15: _t->onSaveMenuParam((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 16: _t->onMenuClicked((*reinterpret_cast<std::add_pointer_t<ActionManager::ActionKind>>(_a[1]))); break;
        case 17: _t->onPaste((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)()>(_a, &WebEngineHandler::targetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(Menu , const QPoint & )>(_a, &WebEngineHandler::requestShowMenu, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(const QString & )>(_a, &WebEngineHandler::requesetCallJsSynchronous, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(QWebEnginePage::WebAction )>(_a, &WebEngineHandler::triggerWebAction, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(VNoteMessageDialogHandler::MessageType )>(_a, &WebEngineHandler::requestMessageDialog, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)()>(_a, &WebEngineHandler::loadRichText, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(const QString & )>(_a, &WebEngineHandler::viewPicture, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(const QString & , int )>(_a, &WebEngineHandler::popupToast, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)(bool )>(_a, &WebEngineHandler::playingVoice, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)()>(_a, &WebEngineHandler::saveAudio, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebEngineHandler::*)()>(_a, &WebEngineHandler::createNote, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QObject**>(_v) = _t->target(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTarget(*reinterpret_cast<QObject**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *WebEngineHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebEngineHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16WebEngineHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WebEngineHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void WebEngineHandler::targetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void WebEngineHandler::requestShowMenu(Menu _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void WebEngineHandler::requesetCallJsSynchronous(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void WebEngineHandler::triggerWebAction(QWebEnginePage::WebAction _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WebEngineHandler::requestMessageDialog(VNoteMessageDialogHandler::MessageType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void WebEngineHandler::loadRichText()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void WebEngineHandler::viewPicture(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void WebEngineHandler::popupToast(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void WebEngineHandler::playingVoice(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void WebEngineHandler::saveAudio()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void WebEngineHandler::createNote()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
