// This file is autogenerated. Changes will be overwritten.
#include "PZONOMFGYT/moc_audio_watcher.cpp"
#include "PZONOMFGYT/moc_gstreamrecorder.cpp"
#include "PZONOMFGYT/moc_recording_curves.cpp"
#include "P66WHCG54J/moc_VNoteMainManager.cpp"
#include "P66WHCG54J/moc_actionmanager.cpp"
#include "P66WHCG54J/moc_jscontent.cpp"
#include "P66WHCG54J/moc_qtplayer.cpp"
#include "P66WHCG54J/moc_setting.cpp"
#include "P66WHCG54J/moc_vlcplayer.cpp"
#include "P66WHCG54J/moc_vnotea2tmanager.cpp"
#include "P66WHCG54J/moc_vnotedatamanager.cpp"
#include "P66WHCG54J/moc_voiceplayerbase.cpp"
#include "P66WHCG54J/moc_vtextspeechandtrmanager.cpp"
#include "P66WHCG54J/moc_webrichetextmanager.cpp"
#include "SQIZ3OIOWK/moc_vnotedbmanager.cpp"
#include "KS3UX4TNHX/moc_VoiceNoteDBusService.cpp"
#include "TFPF5N7OZ5/moc_dbuslogin1manager.cpp"
#include "OVNZZSW2YO/moc_vnote_message_dialog_handler.cpp"
#include "OVNZZSW2YO/moc_voice_player_handler.cpp"
#include "OVNZZSW2YO/moc_voice_recoder_handler.cpp"
#include "OVNZZSW2YO/moc_voice_to_text_handler.cpp"
#include "OVNZZSW2YO/moc_voice_to_text_task_manager.cpp"
#include "OVNZZSW2YO/moc_web_engine_handler.cpp"
#include "FNLYMPYW64/moc_exportnoteworker.cpp"
#include "FNLYMPYW64/moc_filecleanupworker.cpp"
#include "FNLYMPYW64/moc_loadfolderworker.cpp"
#include "FNLYMPYW64/moc_loadiconsworker.cpp"
#include "FNLYMPYW64/moc_loadnoteitemsworker.cpp"
#include "FNLYMPYW64/moc_vnmainwnddelayinittask.cpp"
#include "FNLYMPYW64/moc_vntask.cpp"
