/****************************************************************************
** Meta object code from reading C++ file 'webrichetextmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../common/webrichetextmanager.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webrichetextmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18WebRichTextManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto WebRichTextManager::qt_create_metaobjectdata<qt_meta_tag_ZN18WebRichTextManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WebRichTextManager",
        "needUpdateNote",
        "",
        "noteId",
        "noteTextChanged",
        "updateSearch",
        "scrollChange",
        "isTop",
        "finishedUpdateNote",
        "onLoadFinsh",
        "onSetDataFinsh",
        "updateNote",
        "onUpdateNoteWithResult",
        "VNoteItem*",
        "data",
        "result",
        "insertVoiceItem",
        "voicePath",
        "voiceSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needUpdateNote'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'noteTextChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateSearch'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollChange'
        QtMocHelpers::SignalData<void(const bool &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'finishedUpdateNote'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onLoadFinsh'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onSetDataFinsh'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateNote'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onUpdateNoteWithResult'
        QtMocHelpers::SlotData<void(VNoteItem *, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'insertVoiceItem'
        QtMocHelpers::SlotData<void(const QString &, qint64)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::LongLong, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebRichTextManager, qt_meta_tag_ZN18WebRichTextManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WebRichTextManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WebRichTextManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WebRichTextManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18WebRichTextManagerE_t>.metaTypes,
    nullptr
} };

void WebRichTextManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebRichTextManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needUpdateNote((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->noteTextChanged(); break;
        case 2: _t->updateSearch(); break;
        case 3: _t->scrollChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->finishedUpdateNote(); break;
        case 5: _t->onLoadFinsh(); break;
        case 6: _t->onSetDataFinsh(); break;
        case 7: _t->updateNote(); break;
        case 8: _t->onUpdateNoteWithResult((*reinterpret_cast<std::add_pointer_t<VNoteItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->insertVoiceItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebRichTextManager::*)(int )>(_a, &WebRichTextManager::needUpdateNote, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebRichTextManager::*)()>(_a, &WebRichTextManager::noteTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebRichTextManager::*)()>(_a, &WebRichTextManager::updateSearch, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebRichTextManager::*)(const bool & )>(_a, &WebRichTextManager::scrollChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebRichTextManager::*)()>(_a, &WebRichTextManager::finishedUpdateNote, 4))
            return;
    }
}

const QMetaObject *WebRichTextManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WebRichTextManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18WebRichTextManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int WebRichTextManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void WebRichTextManager::needUpdateNote(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void WebRichTextManager::noteTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void WebRichTextManager::updateSearch()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void WebRichTextManager::scrollChange(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void WebRichTextManager::finishedUpdateNote()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
