/****************************************************************************
** Meta object code from reading C++ file 'dbuslogin1manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dbusservice/dbuslogin1manager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbuslogin1manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DBusLogin1ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusLogin1Manager::qt_create_metaobjectdata<qt_meta_tag_ZN17DBusLogin1ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusLogin1Manager",
        "BlockInhibitedChanged",
        "",
        "PrepareForShutdown",
        "active",
        "PrepareForSleep",
        "SeatNew",
        "id",
        "QDBusObjectPath",
        "path",
        "SeatRemoved",
        "SessionNew",
        "SessionRemoved",
        "UserNew",
        "uid",
        "UserRemoved",
        "__propertyChanged__",
        "QDBusMessage",
        "msg",
        "ActivateSession",
        "QDBusPendingReply<>",
        "ActivateSessionOnSeat",
        "seat",
        "AttachDevice",
        "sysfs",
        "interactive",
        "CanHibernate",
        "QDBusPendingReply<QString>",
        "CanHybridSleep",
        "CanPowerOff",
        "CanReboot",
        "CanSuspend",
        "FlushDevices",
        "GetSeat",
        "QDBusPendingReply<QDBusObjectPath>",
        "GetSession",
        "GetSessionByPID",
        "pid",
        "GetUser",
        "Hibernate",
        "HybridSleep",
        "Inhibit",
        "QDBusPendingReply<QDBusUnixFileDescriptor>",
        "what",
        "who",
        "why",
        "mode",
        "KillSession",
        "signal",
        "KillUser",
        "ListInhibitors",
        "QDBusPendingReply<InhibitorsList>",
        "ListSeats",
        "QDBusPendingReply<SeatList>",
        "ListSessions",
        "QDBusPendingReply<SessionList>",
        "ListUsers",
        "QDBusPendingReply<UserList>",
        "LockSession",
        "LockSessions",
        "PowerOff",
        "Reboot",
        "ReleaseSession",
        "SetUserLinger",
        "b",
        "Suspend",
        "TerminateSeat",
        "TerminateSession",
        "TerminateUser",
        "UnlockSession",
        "UnlockSessions",
        "BlockInhibited",
        "ControlGroupHierarchy",
        "Controllers",
        "DelayInhibited",
        "HandleHibernateKey",
        "HandleLidSwitch",
        "HandlePowerKey",
        "HandleSuspendKey",
        "IdleAction",
        "IdleActionUSec",
        "IdleHint",
        "IdleSinceHint",
        "IdleSinceHintMonotonic",
        "InhibitDelayMaxUSec",
        "KillExcludeUsers",
        "KillOnlyUsers",
        "KillUserProcesses",
        "NAutoVTs",
        "PreparingForShutdown",
        "PreparingForSleep",
        "ResetControllers"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'BlockInhibitedChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PrepareForShutdown'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'PrepareForSleep'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'SeatNew'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'SeatRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'SessionNew'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'SessionRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QDBusObjectPath &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'UserNew'
        QtMocHelpers::SignalData<void(uint, const QDBusObjectPath &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'UserRemoved'
        QtMocHelpers::SignalData<void(uint, const QDBusObjectPath &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot '__propertyChanged__'
        QtMocHelpers::SlotData<void(const QDBusMessage &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'ActivateSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'ActivateSessionOnSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(21, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 22 },
        }}),
        // Slot 'AttachDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, bool)>(23, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'CanHibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(26, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'CanHybridSleep'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(28, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'CanPowerOff'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(29, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'CanReboot'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(30, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'CanSuspend'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(31, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'FlushDevices'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(32, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'GetSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'GetSession'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'GetSessionByPID'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(uint)>(36, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::UInt, 37 },
        }}),
        // Slot 'GetUser'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(uint)>(38, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::UInt, 14 },
        }}),
        // Slot 'Hibernate'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(39, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'HybridSleep'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(40, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'Inhibit'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusUnixFileDescriptor>(const QString &, const QString &, const QString &, const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 42, {{
            { QMetaType::QString, 43 }, { QMetaType::QString, 44 }, { QMetaType::QString, 45 }, { QMetaType::QString, 46 },
        }}),
        // Slot 'KillSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &)>(47, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 44 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'KillUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, const QString &)>(49, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 14 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'ListInhibitors'
        QtMocHelpers::SlotData<QDBusPendingReply<InhibitorsList>()>(50, 2, QMC::AccessPublic, 0x80000000 | 51),
        // Slot 'ListSeats'
        QtMocHelpers::SlotData<QDBusPendingReply<SeatList>()>(52, 2, QMC::AccessPublic, 0x80000000 | 53),
        // Slot 'ListSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<SessionList>()>(54, 2, QMC::AccessPublic, 0x80000000 | 55),
        // Slot 'ListUsers'
        QtMocHelpers::SlotData<QDBusPendingReply<UserList>()>(56, 2, QMC::AccessPublic, 0x80000000 | 57),
        // Slot 'LockSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(58, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'LockSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(59, 2, QMC::AccessPublic, 0x80000000 | 20),
        // Slot 'PowerOff'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(60, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'Reboot'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(61, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'ReleaseSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(62, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'SetUserLinger'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint, bool, bool)>(63, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 14 }, { QMetaType::Bool, 64 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'Suspend'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(65, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'TerminateSeat'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(66, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'TerminateSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(67, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'TerminateUser'
        QtMocHelpers::SlotData<QDBusPendingReply<>(uint)>(68, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::UInt, 14 },
        }}),
        // Slot 'UnlockSession'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(69, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'UnlockSessions'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(70, 2, QMC::AccessPublic, 0x80000000 | 20),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BlockInhibited'
        QtMocHelpers::PropertyData<QString>(71, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'ControlGroupHierarchy'
        QtMocHelpers::PropertyData<QString>(72, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'Controllers'
        QtMocHelpers::PropertyData<QStringList>(73, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'DelayInhibited'
        QtMocHelpers::PropertyData<QString>(74, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HandleHibernateKey'
        QtMocHelpers::PropertyData<QString>(75, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HandleLidSwitch'
        QtMocHelpers::PropertyData<QString>(76, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HandlePowerKey'
        QtMocHelpers::PropertyData<QString>(77, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'HandleSuspendKey'
        QtMocHelpers::PropertyData<QString>(78, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdleAction'
        QtMocHelpers::PropertyData<QString>(79, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'IdleActionUSec'
        QtMocHelpers::PropertyData<qulonglong>(80, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'IdleHint'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'IdleSinceHint'
        QtMocHelpers::PropertyData<qulonglong>(82, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'IdleSinceHintMonotonic'
        QtMocHelpers::PropertyData<qulonglong>(83, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'InhibitDelayMaxUSec'
        QtMocHelpers::PropertyData<qulonglong>(84, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'KillExcludeUsers'
        QtMocHelpers::PropertyData<QStringList>(85, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'KillOnlyUsers'
        QtMocHelpers::PropertyData<QStringList>(86, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'KillUserProcesses'
        QtMocHelpers::PropertyData<bool>(87, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'NAutoVTs'
        QtMocHelpers::PropertyData<uint>(88, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'PreparingForShutdown'
        QtMocHelpers::PropertyData<bool>(89, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'PreparingForSleep'
        QtMocHelpers::PropertyData<bool>(90, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'ResetControllers'
        QtMocHelpers::PropertyData<QStringList>(91, QMetaType::QStringList, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusLogin1Manager, qt_meta_tag_ZN17DBusLogin1ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusLogin1Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusLogin1ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusLogin1ManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DBusLogin1ManagerE_t>.metaTypes,
    nullptr
} };

void DBusLogin1Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusLogin1Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->BlockInhibitedChanged(); break;
        case 1: _t->PrepareForShutdown((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->PrepareForSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->SeatNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 4: _t->SeatRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 5: _t->SessionNew((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 6: _t->SessionRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 7: _t->UserNew((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 8: _t->UserRemoved((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 9: _t->__propertyChanged__((*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[1]))); break;
        case 10: { QDBusPendingReply<> _r = _t->ActivateSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->ActivateSessionOnSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->AttachDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->CanHibernate();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QString> _r = _t->CanHybridSleep();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QString> _r = _t->CanPowerOff();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QString> _r = _t->CanReboot();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QString> _r = _t->CanSuspend();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->FlushDevices((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetSessionByPID((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<QDBusObjectPath> _r = _t->GetUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->Hibernate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->HybridSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<QDBusUnixFileDescriptor> _r = _t->Inhibit((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusUnixFileDescriptor>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->KillSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->KillUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<InhibitorsList> _r = _t->ListInhibitors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<InhibitorsList>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<SeatList> _r = _t->ListSeats();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<SeatList>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<SessionList> _r = _t->ListSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<SessionList>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<UserList> _r = _t->ListUsers();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<UserList>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<> _r = _t->LockSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->LockSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->PowerOff((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<> _r = _t->Reboot((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<> _r = _t->ReleaseSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->SetUserLinger((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->Suspend((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->TerminateSeat((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->TerminateSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<> _r = _t->TerminateUser((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<> _r = _t->UnlockSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<> _r = _t->UnlockSessions();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)()>(_a, &DBusLogin1Manager::BlockInhibitedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(bool )>(_a, &DBusLogin1Manager::PrepareForShutdown, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(bool )>(_a, &DBusLogin1Manager::PrepareForSleep, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::SeatNew, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::SeatRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::SessionNew, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(const QString & , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::SessionRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(uint , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::UserNew, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusLogin1Manager::*)(uint , const QDBusObjectPath & )>(_a, &DBusLogin1Manager::UserRemoved, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->blockInhibited(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->controlGroupHierarchy(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->controllers(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->delayInhibited(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->handleHibernateKey(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->handleLidSwitch(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->handlePowerKey(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->handleSuspendKey(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->idleAction(); break;
        case 9: *reinterpret_cast<qulonglong*>(_v) = _t->idleActionUSec(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->idleHint(); break;
        case 11: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHint(); break;
        case 12: *reinterpret_cast<qulonglong*>(_v) = _t->idleSinceHintMonotonic(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->inhibitDelayMaxUSec(); break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->killExcludeUsers(); break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->killOnlyUsers(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->killUserProcesses(); break;
        case 17: *reinterpret_cast<uint*>(_v) = _t->nAutoVTs(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->preparingForShutdown(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->preparingForSleep(); break;
        case 20: *reinterpret_cast<QStringList*>(_v) = _t->resetControllers(); break;
        default: break;
        }
    }
}

const QMetaObject *DBusLogin1Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusLogin1Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DBusLogin1ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusLogin1Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void DBusLogin1Manager::BlockInhibitedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DBusLogin1Manager::PrepareForShutdown(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DBusLogin1Manager::PrepareForSleep(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DBusLogin1Manager::SeatNew(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DBusLogin1Manager::SeatRemoved(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DBusLogin1Manager::SessionNew(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void DBusLogin1Manager::SessionRemoved(const QString & _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void DBusLogin1Manager::UserNew(uint _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void DBusLogin1Manager::UserRemoved(uint _t1, const QDBusObjectPath & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}
QT_WARNING_POP
