/****************************************************************************
** Meta object code from reading C++ file 'actionmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../common/actionmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actionmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ActionManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionManager::qt_create_metaobjectdata<qt_meta_tag_ZN13ActionManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionManager",
        "actionTriggered",
        "",
        "ActionKind",
        "actionId",
        "actionTriggerFromQuick",
        "getActionById",
        "id",
        "enableAction",
        "enable",
        "visibleAction",
        "visible",
        "resetCtxMenu",
        "MenuType",
        "type",
        "visibleAiActions",
        "visibleMulChoicesActions",
        "enableVoicePlayActions",
        "actionText",
        "actionCompType",
        "ComponentType",
        "childActions",
        "QVariantList",
        "setActionObject",
        "obj",
        "Invalid",
        "NotebookMenuBase",
        "NotebookRename",
        "NotebookDelete",
        "NotebookAddNew",
        "NotebookMenuMax",
        "NoteMenuBase",
        "NoteRename",
        "NoteTop",
        "NoteMove",
        "NoteDelete",
        "NoteSave",
        "NoteSaveVoice",
        "NoteSeparator",
        "NoteAddNew",
        "NoteMenuMax",
        "VoiceMenuBase",
        "VoiceAsSave",
        "VoiceToText",
        "VoiceDelete",
        "VoiceSelectAll",
        "VoiceCopy",
        "VoiceCut",
        "VoicePaste",
        "VoiceMenuMax",
        "PictureMenuBase",
        "PictureView",
        "PictureDelete",
        "PictureSelectAll",
        "PictureCopy",
        "PictureCut",
        "PicturePaste",
        "PictureSaveAs",
        "PictureMenuMax",
        "TxtMenuBase",
        "TxtDelete",
        "TxtSelectAll",
        "TxtCopy",
        "TxtCut",
        "TxtPaste",
        "TxtSeparator",
        "TxtSpeech",
        "TxtStopreading",
        "TxtDictation",
        "TxtMenuMax",
        "SaveNoteMenuBase",
        "SaveNoteAsHtml",
        "SaveNoteAsText",
        "SaveNoteMax",
        "MenuMaxId",
        "UnknownMenu",
        "NotebookCtxMenu",
        "NoteCtxMenu",
        "VoiceCtxMenu",
        "PictureCtxMenu",
        "TxtCtxMenu",
        "SaveNoteCtxMenu",
        "MenuItemComponent",
        "MenuComponent",
        "MenuSeparatorComponent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'actionTriggered'
        QtMocHelpers::SignalData<void(enum ActionKind)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'actionTriggerFromQuick'
        QtMocHelpers::SlotData<void(enum ActionKind)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Method 'getActionById'
        QtMocHelpers::MethodData<QObject *(enum ActionKind)>(6, 2, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'enableAction'
        QtMocHelpers::MethodData<void(enum ActionKind, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 9 },
        }}),
        // Method 'visibleAction'
        QtMocHelpers::MethodData<void(enum ActionKind, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 11 },
        }}),
        // Method 'resetCtxMenu'
        QtMocHelpers::MethodData<void(enum MenuType, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Bool, 9 },
        }}),
        // Method 'resetCtxMenu'
        QtMocHelpers::MethodData<void(enum MenuType)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'visibleAiActions'
        QtMocHelpers::MethodData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Method 'visibleMulChoicesActions'
        QtMocHelpers::MethodData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Method 'enableVoicePlayActions'
        QtMocHelpers::MethodData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Method 'actionText'
        QtMocHelpers::MethodData<QString(enum ActionKind)>(18, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'actionCompType'
        QtMocHelpers::MethodData<enum ComponentType(enum ActionKind)>(19, 2, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'childActions'
        QtMocHelpers::MethodData<QVariantList(enum ActionKind)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Method 'setActionObject'
        QtMocHelpers::MethodData<void(enum ActionKind, QObject *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 }, { QMetaType::QObjectStar, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ActionKind'
        QtMocHelpers::EnumData<enum ActionKind>(3, 3, QMC::EnumFlags{}).add({
            {   25, ActionKind::Invalid },
            {   26, ActionKind::NotebookMenuBase },
            {   27, ActionKind::NotebookRename },
            {   28, ActionKind::NotebookDelete },
            {   29, ActionKind::NotebookAddNew },
            {   30, ActionKind::NotebookMenuMax },
            {   31, ActionKind::NoteMenuBase },
            {   32, ActionKind::NoteRename },
            {   33, ActionKind::NoteTop },
            {   34, ActionKind::NoteMove },
            {   35, ActionKind::NoteDelete },
            {   36, ActionKind::NoteSave },
            {   37, ActionKind::NoteSaveVoice },
            {   38, ActionKind::NoteSeparator },
            {   39, ActionKind::NoteAddNew },
            {   40, ActionKind::NoteMenuMax },
            {   41, ActionKind::VoiceMenuBase },
            {   42, ActionKind::VoiceAsSave },
            {   43, ActionKind::VoiceToText },
            {   44, ActionKind::VoiceDelete },
            {   45, ActionKind::VoiceSelectAll },
            {   46, ActionKind::VoiceCopy },
            {   47, ActionKind::VoiceCut },
            {   48, ActionKind::VoicePaste },
            {   49, ActionKind::VoiceMenuMax },
            {   50, ActionKind::PictureMenuBase },
            {   51, ActionKind::PictureView },
            {   52, ActionKind::PictureDelete },
            {   53, ActionKind::PictureSelectAll },
            {   54, ActionKind::PictureCopy },
            {   55, ActionKind::PictureCut },
            {   56, ActionKind::PicturePaste },
            {   57, ActionKind::PictureSaveAs },
            {   58, ActionKind::PictureMenuMax },
            {   59, ActionKind::TxtMenuBase },
            {   60, ActionKind::TxtDelete },
            {   61, ActionKind::TxtSelectAll },
            {   62, ActionKind::TxtCopy },
            {   63, ActionKind::TxtCut },
            {   64, ActionKind::TxtPaste },
            {   65, ActionKind::TxtSeparator },
            {   66, ActionKind::TxtSpeech },
            {   67, ActionKind::TxtStopreading },
            {   68, ActionKind::TxtDictation },
            {   69, ActionKind::TxtMenuMax },
            {   70, ActionKind::SaveNoteMenuBase },
            {   71, ActionKind::SaveNoteAsHtml },
            {   72, ActionKind::SaveNoteAsText },
            {   73, ActionKind::SaveNoteMax },
            {   74, ActionKind::MenuMaxId },
        }),
        // enum 'MenuType'
        QtMocHelpers::EnumData<enum MenuType>(13, 13, QMC::EnumFlags{}).add({
            {   75, MenuType::UnknownMenu },
            {   76, MenuType::NotebookCtxMenu },
            {   77, MenuType::NoteCtxMenu },
            {   78, MenuType::VoiceCtxMenu },
            {   79, MenuType::PictureCtxMenu },
            {   80, MenuType::TxtCtxMenu },
            {   81, MenuType::SaveNoteCtxMenu },
        }),
        // enum 'ComponentType'
        QtMocHelpers::EnumData<enum ComponentType>(20, 20, QMC::EnumFlags{}).add({
            {   82, ComponentType::MenuItemComponent },
            {   83, ComponentType::MenuComponent },
            {   84, ComponentType::MenuSeparatorComponent },
        }),
    };
    return QtMocHelpers::metaObjectData<ActionManager, qt_meta_tag_ZN13ActionManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActionManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ActionManagerE_t>.metaTypes,
    nullptr
} };

void ActionManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->actionTriggered((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1]))); break;
        case 1: _t->actionTriggerFromQuick((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1]))); break;
        case 2: { QObject* _r = _t->getActionById((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 3: _t->enableAction((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->visibleAction((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->resetCtxMenu((*reinterpret_cast<std::add_pointer_t<enum MenuType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->resetCtxMenu((*reinterpret_cast<std::add_pointer_t<enum MenuType>>(_a[1]))); break;
        case 7: _t->visibleAiActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->visibleMulChoicesActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->enableVoicePlayActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: { QString _r = _t->actionText((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 11: { enum ComponentType _r = _t->actionCompType((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])));
            if (_a[0]) *reinterpret_cast<enum ComponentType*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVariantList _r = _t->childActions((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setActionObject((*reinterpret_cast<std::add_pointer_t<enum ActionKind>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActionManager::*)(ActionKind )>(_a, &ActionManager::actionTriggered, 0))
            return;
    }
}

const QMetaObject *ActionManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActionManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ActionManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ActionManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void ActionManager::actionTriggered(ActionKind _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
