/****************************************************************************
** Meta object code from reading C++ file 'vnote_message_dialog_handler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../handler/vnote_message_dialog_handler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vnote_message_dialog_handler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto VNoteMessageDialogHandler::qt_create_metaobjectdata<qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VNoteMessageDialogHandler",
        "messageTypeChanged",
        "",
        "messageDataChanged",
        "mainMessageChanged",
        "detailMessageChanged",
        "warnConfirmChanged",
        "singleButtonChanged",
        "messageType",
        "MessageType",
        "messageData",
        "QVariant",
        "mainMessage",
        "detailMessage",
        "warnConfirm",
        "singleButton",
        "None",
        "DeleteNote",
        "AbortRecord",
        "DeleteFolder",
        "AsrTimeLimit",
        "AborteAsr",
        "VolumeTooLow",
        "CutNote",
        "SaveFailed",
        "NoPermission",
        "VoicePathNoAvail",
        "NoNetwork"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'messageTypeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'messageDataChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mainMessageChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'detailMessageChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'warnConfirmChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'singleButtonChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'messageType'
        QtMocHelpers::PropertyData<enum MessageType>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'messageData'
        QtMocHelpers::PropertyData<QVariant>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'mainMessage'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'detailMessage'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'warnConfirm'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'singleButton'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MessageType'
        QtMocHelpers::EnumData<enum MessageType>(9, 9, QMC::EnumFlags{}).add({
            {   16, MessageType::None },
            {   17, MessageType::DeleteNote },
            {   18, MessageType::AbortRecord },
            {   19, MessageType::DeleteFolder },
            {   20, MessageType::AsrTimeLimit },
            {   21, MessageType::AborteAsr },
            {   22, MessageType::VolumeTooLow },
            {   23, MessageType::CutNote },
            {   24, MessageType::SaveFailed },
            {   25, MessageType::NoPermission },
            {   26, MessageType::VoicePathNoAvail },
            {   27, MessageType::NoNetwork },
        }),
    };
    return QtMocHelpers::metaObjectData<VNoteMessageDialogHandler, qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VNoteMessageDialogHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>.metaTypes,
    nullptr
} };

void VNoteMessageDialogHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VNoteMessageDialogHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->messageTypeChanged(); break;
        case 1: _t->messageDataChanged(); break;
        case 2: _t->mainMessageChanged(); break;
        case 3: _t->detailMessageChanged(); break;
        case 4: _t->warnConfirmChanged(); break;
        case 5: _t->singleButtonChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::messageTypeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::messageDataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::mainMessageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::detailMessageChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::warnConfirmChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VNoteMessageDialogHandler::*)()>(_a, &VNoteMessageDialogHandler::singleButtonChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum MessageType*>(_v) = _t->messageType(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->messageData(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->mainMessage(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->detailMessage(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->warnConfirm(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->singleButton(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMessageType(*reinterpret_cast<enum MessageType*>(_v)); break;
        case 1: _t->setMessageData(*reinterpret_cast<QVariant*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *VNoteMessageDialogHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VNoteMessageDialogHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25VNoteMessageDialogHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int VNoteMessageDialogHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void VNoteMessageDialogHandler::messageTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void VNoteMessageDialogHandler::messageDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void VNoteMessageDialogHandler::mainMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void VNoteMessageDialogHandler::detailMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void VNoteMessageDialogHandler::warnConfirmChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void VNoteMessageDialogHandler::singleButtonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
