/****************************************************************************
** Meta object code from reading C++ file 'voice_recoder_handler.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../handler/voice_recoder_handler.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'voice_recoder_handler.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19VoiceRecoderHandlerE_t {};
} // unnamed namespace

template <> constexpr inline auto VoiceRecoderHandler::qt_create_metaobjectdata<qt_meta_tag_ZN19VoiceRecoderHandlerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VoiceRecoderHandler",
        "recoderStateChange",
        "",
        "RecoderType",
        "type",
        "finishedRecod",
        "path",
        "voiceSize",
        "recoderDurationChange",
        "duation",
        "updateRecorderTime",
        "QVariant",
        "time",
        "updateWave",
        "max",
        "updateRecordBtnState",
        "enable",
        "volumeTooLow",
        "isLow",
        "onDeviceEnableChanged",
        "mode",
        "enabled",
        "onAudioDeviceChange",
        "onAudioBufferProbed",
        "QAudioBuffer",
        "buffer",
        "onReduceNoiseChanged",
        "reduceNoiseChanged",
        "getRecoderType",
        "startRecoder",
        "stopRecoder",
        "pauseRecoder",
        "setAudioDevice",
        "device",
        "changeMode",
        "confirmStartRecoder",
        "hasAudioOutputDevice",
        "hasAudioInputDevice",
        "Idle",
        "Recording",
        "Paused"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recoderStateChange'
        QtMocHelpers::SignalData<void(enum RecoderType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finishedRecod'
        QtMocHelpers::SignalData<void(const QString &, qint64)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::LongLong, 7 },
        }}),
        // Signal 'recoderDurationChange'
        QtMocHelpers::SignalData<void(qint64)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Signal 'updateRecorderTime'
        QtMocHelpers::SignalData<void(const QVariant &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'updateWave'
        QtMocHelpers::SignalData<void(qreal)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 14 },
        }}),
        // Signal 'updateRecordBtnState'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'volumeTooLow'
        QtMocHelpers::SignalData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'onDeviceEnableChanged'
        QtMocHelpers::SlotData<void(int, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'onAudioDeviceChange'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'onAudioBufferProbed'
        QtMocHelpers::SlotData<void(const QAudioBuffer &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'onReduceNoiseChanged'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Method 'getRecoderType'
        QtMocHelpers::MethodData<enum RecoderType()>(28, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'startRecoder'
        QtMocHelpers::MethodData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'stopRecoder'
        QtMocHelpers::MethodData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'pauseRecoder'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setAudioDevice'
        QtMocHelpers::MethodData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Method 'changeMode'
        QtMocHelpers::MethodData<void(const int &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Method 'confirmStartRecoder'
        QtMocHelpers::MethodData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'hasAudioOutputDevice'
        QtMocHelpers::MethodData<bool()>(36, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'hasAudioInputDevice'
        QtMocHelpers::MethodData<bool()>(37, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RecoderType'
        QtMocHelpers::EnumData<enum RecoderType>(3, 3, QMC::EnumFlags{}).add({
            {   38, RecoderType::Idle },
            {   39, RecoderType::Recording },
            {   40, RecoderType::Paused },
        }),
    };
    return QtMocHelpers::metaObjectData<VoiceRecoderHandler, qt_meta_tag_ZN19VoiceRecoderHandlerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VoiceRecoderHandler::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VoiceRecoderHandlerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VoiceRecoderHandlerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19VoiceRecoderHandlerE_t>.metaTypes,
    nullptr
} };

void VoiceRecoderHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VoiceRecoderHandler *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recoderStateChange((*reinterpret_cast<std::add_pointer_t<enum RecoderType>>(_a[1]))); break;
        case 1: _t->finishedRecod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[2]))); break;
        case 2: _t->recoderDurationChange((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->updateRecorderTime((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 4: _t->updateWave((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 5: _t->updateRecordBtnState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->volumeTooLow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->onDeviceEnableChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->onAudioDeviceChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->onAudioBufferProbed((*reinterpret_cast<std::add_pointer_t<QAudioBuffer>>(_a[1]))); break;
        case 10: _t->onReduceNoiseChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: { enum RecoderType _r = _t->getRecoderType();
            if (_a[0]) *reinterpret_cast<enum RecoderType*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->startRecoder(); break;
        case 13: _t->stopRecoder(); break;
        case 14: _t->pauseRecoder(); break;
        case 15: _t->setAudioDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->changeMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->confirmStartRecoder(); break;
        case 18: { bool _r = _t->hasAudioOutputDevice();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->hasAudioInputDevice();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(RecoderType )>(_a, &VoiceRecoderHandler::recoderStateChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(const QString & , qint64 )>(_a, &VoiceRecoderHandler::finishedRecod, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(qint64 )>(_a, &VoiceRecoderHandler::recoderDurationChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(const QVariant & )>(_a, &VoiceRecoderHandler::updateRecorderTime, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(qreal )>(_a, &VoiceRecoderHandler::updateWave, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(bool )>(_a, &VoiceRecoderHandler::updateRecordBtnState, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VoiceRecoderHandler::*)(bool )>(_a, &VoiceRecoderHandler::volumeTooLow, 6))
            return;
    }
}

const QMetaObject *VoiceRecoderHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VoiceRecoderHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19VoiceRecoderHandlerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int VoiceRecoderHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void VoiceRecoderHandler::recoderStateChange(RecoderType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VoiceRecoderHandler::finishedRecod(const QString & _t1, qint64 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void VoiceRecoderHandler::recoderDurationChange(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void VoiceRecoderHandler::updateRecorderTime(const QVariant & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void VoiceRecoderHandler::updateWave(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void VoiceRecoderHandler::updateRecordBtnState(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void VoiceRecoderHandler::volumeTooLow(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
